//
//  DOMWriterTest.cpp
//
//  Created  by Setsu on 8/1/2010.
//  Modified by Setsu on May 30, 2013.
//  Copyright 2010-2013 RoundSquare Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
// 
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

//----------------------------------------
//	include
//----------------------------------------
#include <Poco/DOM/DOMWriter.h>
#include <Poco/DOM/Document.h>
#include <Poco/DOM/Element.h>
#include <Poco/DOM/Attr.h>
#include <Poco/DOM/Text.h>
#include <Poco/XML/XMLWriter.h>
#include <Poco/DOM/AutoPtr.h>
#include <Poco/DOM/DocumentType.h>
#include <Poco/DOM/DOMImplementation.h>

#include <string>
#include <iostream>
#include <sstream>

#include "ScopedLogMessage.h"
#include "PrepareConsoleLogger.h"

//----------------------------------------
//	TestDOMWriter
//----------------------------------------
void TestDOMWriter(bool writeXMLDeclaration, const std::string& newLineCharacters)
{
	Poco::XML::DOMWriter writer;

	int options = (writeXMLDeclaration ? Poco::XML::XMLWriter::WRITE_XML_DECLARATION : Poco::XML::XMLWriter::CANONICAL) |
					Poco::XML::XMLWriter::PRETTY_PRINT;
	writer.setOptions(options);
	writer.setNewLine(newLineCharacters);

	Poco::XML::AutoPtr<Poco::XML::DocumentType>
		pDoctype = Poco::XML::DOMImplementation::instance().createDocumentType(
						"html",
						"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd",
						"");

	Poco::XML::AutoPtr<Poco::XML::Document> pDoc = new Poco::XML::Document(pDoctype);

	Poco::XML::AutoPtr<Poco::XML::Element> pRoot = pDoc->createElement("html");
	pRoot->setAttribute("xmlns", "http://www.w3.org/1999/xhtml");
	pDoc->appendChild(pRoot);

	Poco::XML::AutoPtr<Poco::XML::Element> pElem1 = pDoc->createElement("head");
	pRoot->appendChild(pElem1);

	Poco::XML::AutoPtr<Poco::XML::Element> pElem10 = pDoc->createElement("title");
	pElem1->appendChild(pElem10);
	Poco::XML::AutoPtr<Poco::XML::Text> pText10 = pDoc->createTextNode("Sample HTML");
	pElem10->appendChild(pText10);

	Poco::XML::AutoPtr<Poco::XML::Element> pElem11 = pDoc->createElement("meta");
	pElem11->setAttribute("http-equiv", "content-type");
	pElem11->setAttribute("content", "text/html; charset=utf-8");
	pElem1->appendChild(pElem11);

	Poco::XML::AutoPtr<Poco::XML::Element> pElem12 = pDoc->createElement("link");
	pElem12->setAttribute("rel", "stylesheet");
	pElem12->setAttribute("href", "css/styles.css");
	pElem12->setAttribute("type", "text/css");
	pElem1->appendChild(pElem12);

	Poco::XML::AutoPtr<Poco::XML::Element> pElem2 = pDoc->createElement("body");
	pRoot->appendChild(pElem2);
	Poco::XML::AutoPtr<Poco::XML::Text> pText2 = pDoc->createTextNode("This is a sample.");
	pElem2->appendChild(pText2);

	std::ostringstream ostr;
	writer.writeNode(ostr, pDoc);
	std::cout << ostr.str();
}

//----------------------------------------
//	main
//----------------------------------------
int main(int /*argc*/, char** /*argv*/)
{
	PrepareConsoleLogger logger(Poco::Logger::ROOT, Poco::Message::PRIO_INFORMATION);

	ScopedLogMessage msg("DOMWriterTest ", "start", "end");

	TestDOMWriter(true, Poco::XML::XMLWriter::NEWLINE_LF);

	return 0;
}
